@@ -1,14 +1,12 @@
-context("calculate")
-
 # calculate arguments
 test_that("x is a tibble", {
   vec <- 1:10
-  expect_error(calculate(vec, stat = "mean"))
+  expect_snapshot(error = TRUE, calculate(vec, stat = "mean"))
 })
 
 test_that("calculate checks `stat` argument", {
   # stat is a string
-  expect_error(calculate(gss_tbl, stat = 3))
+  expect_snapshot(error = TRUE, calculate(gss_tbl, stat = 3))
 
   # stat is one of the implemented options with informative error
   gen_gss_slope <- gss_tbl %>%
@@ -16,21 +14,17 @@ test_that("calculate checks `stat` argument", {
     hypothesize(null = "independence") %>%
     generate(reps = 10, type = "permute")
 
-  expect_error(
-    calculate(gen_gss_slope, stat = "slopee"),
-    '`stat` must be one of.*Did you mean "slope"'
+  expect_snapshot(error = TRUE,
+    calculate(gen_gss_slope, stat = "slopee")
   )
-  expect_error(
-    calculate(gen_gss_slope, stat = "stdev"),
-    "`stat` must be one of"
+  expect_snapshot(error = TRUE,
+    calculate(gen_gss_slope, stat = "stdev")
   )
-  expect_error(
-    calculate(gen_gss_slope, stat = "stat"),
-    "`stat` must be one of"
+  expect_snapshot(error = TRUE,
+    calculate(gen_gss_slope, stat = "stat")
   )
-  expect_error(
-    calculate(gen_gss_slope, stat = "chi sq"),
-    '`stat` must be one of.*Did you mean "Chisq"'
+  expect_snapshot(error = TRUE,
+    calculate(gen_gss_slope, stat = "chi sq")
   )
 
   # stat can be one of the allowed aliases
@@ -48,21 +42,19 @@ test_that("calculate checks `stat` argument", {
 })
 
 test_that("errors informatively with incompatible stat vs hypothesis", {
-  expect_error(
+  expect_snapshot(error = TRUE,
     gss %>%
       specify(college ~ sex, success = "degree") %>%
       hypothesise(null = "point", p = .40) %>%
-      calculate(stat = "diff in props", order = c("female", "male")),
-    'statistic \\`stat = "diff in props"\\` is incompatible'
+      calculate(stat = "diff in props", order = c("female", "male"))
   )
 
-  expect_error(
+  expect_snapshot(error = TRUE,
     gss %>%
       specify(college ~ sex, success = "degree") %>%
       hypothesise(null = "point", p = .40) %>%
       generate(reps = 10, type = "draw") %>%
-      calculate(stat = "diff in props", order = c("female", "male")),
-    'statistic \\`stat = "diff in props"\\` is incompatible'
+      calculate(stat = "diff in props", order = c("female", "male"))
   )
 
   expect_silent(
@@ -87,7 +79,7 @@ test_that("errors informatively with incompatible stat vs hypothesis", {
 })
 
 test_that("response attribute has been set", {
-  expect_error(
+  expect_snapshot(error = TRUE,
     tibble::as_tibble(gss) %>% calculate(stat = "median")
   )
 })
@@ -101,34 +93,34 @@ test_that("variable chosen is of appropriate class (one var problems)", {
       p = c("dem" = .5, "rep" = .25, "ind" = .25)
     ) %>%
     generate(reps = 10, type = "draw")
-  expect_error(calculate(gen_gss1, stat = "mean"))
+  expect_snapshot(error = TRUE, calculate(gen_gss1, stat = "mean"))
 
   # One mean example
   gen_gss_num <- gss_tbl %>%
     specify(hours ~ NULL) %>%
     hypothesize(null = "point", mu = 40) %>%
     generate(reps = 10, type = "bootstrap")
-  expect_error(calculate(gen_gss_num, stat = "prop"))
+  expect_snapshot(error = TRUE, calculate(gen_gss_num, stat = "prop"))
   expect_silent(calculate(gen_gss_num, stat = "mean"))
-  expect_error(calculate(gen_gss_num, stat = "median"))
-  expect_error(calculate(gen_gss_num, stat = "sd"))
+  expect_snapshot(error = TRUE, calculate(gen_gss_num, stat = "median"))
+  expect_snapshot(error = TRUE, calculate(gen_gss_num, stat = "sd"))
 
   gen_gss_num2 <- gss_tbl %>%
     specify(hours ~ NULL) %>%
     hypothesize(null = "point", med = 40) %>%
     generate(reps = 10, type = "bootstrap")
-  expect_error(calculate(gen_gss_num2, stat = "prop"))
-  expect_error(calculate(gen_gss_num2, stat = "mean"))
+  expect_snapshot(error = TRUE, calculate(gen_gss_num2, stat = "prop"))
+  expect_snapshot(error = TRUE, calculate(gen_gss_num2, stat = "mean"))
   expect_silent(calculate(gen_gss_num2, stat = "median"))
-  expect_error(calculate(gen_gss_num2, stat = "sd"))
+  expect_snapshot(error = TRUE, calculate(gen_gss_num2, stat = "sd"))
 
   gen_gss_num3 <- gss_tbl %>%
     specify(hours ~ NULL) %>%
     hypothesize(null = "point", sigma = 0.6) %>%
     generate(reps = 10, type = "bootstrap")
-  expect_error(calculate(gen_gss_num3, stat = "prop"))
-  expect_error(calculate(gen_gss_num3, stat = "mean"))
-  expect_error(calculate(gen_gss_num3, stat = "median"))
+  expect_snapshot(error = TRUE, calculate(gen_gss_num3, stat = "prop"))
+  expect_snapshot(error = TRUE, calculate(gen_gss_num3, stat = "mean"))
+  expect_snapshot(error = TRUE, calculate(gen_gss_num3, stat = "median"))
   expect_silent(calculate(gen_gss_num3, stat = "sd"))
 })
 
@@ -137,8 +129,8 @@ test_that("grouping (explanatory) variable is a factor (two var problems)", {
     specify(hours ~ age) %>%
     hypothesize(null = "independence") %>%
     generate(reps = 10, type = "permute")
-  expect_error(calculate(gen_gss2, stat = "diff in means"))
-  expect_error(calculate(gen_gss2, stat = "diff in medians"))
+  expect_snapshot(error = TRUE, calculate(gen_gss2, stat = "diff in means"))
+  expect_snapshot(error = TRUE, calculate(gen_gss2, stat = "diff in medians"))
   # Since shifts to "Slope with t"
   ## Not implemented
   # expect_silent(calculate(gen_gss2, stat = "t"))
@@ -149,10 +141,10 @@ test_that("grouping (explanatory) variable is numeric (two var problems)", {
     specify(partyid ~ hours) %>%
     hypothesize(null = "independence") %>%
     generate(reps = 10, type = "permute")
-  expect_error(calculate(gen_gss2a, stat = "slope"))
+  expect_snapshot(error = TRUE, calculate(gen_gss2a, stat = "slope"))
   # Since shifts to "Slope with t"
-  expect_error(calculate(gen_gss2a, stat = "t"))
-  expect_error(calculate(gen_gss2a, stat = "diff in medians"))
+  expect_snapshot(error = TRUE, calculate(gen_gss2a, stat = "t"))
+  expect_snapshot(error = TRUE, calculate(gen_gss2a, stat = "diff in medians"))
 })
 
 test_that("response variable is a factor (two var problems)", {
@@ -160,18 +152,18 @@ test_that("response variable is a factor (two var problems)", {
     specify(hours ~ partyid) %>%
     hypothesize(null = "independence") %>%
     generate(reps = 10, type = "permute")
-  expect_error(calculate(gen_gss3, stat = "Chisq"))
+  expect_snapshot(error = TRUE, calculate(gen_gss3, stat = "Chisq"))
 
   # explanatory has more than 2 levels
   gen_gss4 <- gss_tbl %>%
     specify(sex ~ partyid, success = "female") %>%
     hypothesize(null = "independence") %>%
     generate(reps = 10, type = "permute")
-  expect_error(calculate(gen_gss4, stat = "diff in props"))
-  expect_error(calculate(gen_gss4, stat = "ratio of props"))
-  expect_error(calculate(gen_gss4, stat = "odds ratio"))
+  expect_snapshot(error = TRUE, calculate(gen_gss4, stat = "diff in props"))
+  expect_snapshot(error = TRUE, calculate(gen_gss4, stat = "ratio of props"))
+  expect_snapshot(error = TRUE, calculate(gen_gss4, stat = "odds ratio"))
 
-  expect_error(calculate(gen_gss4, stat = "t"))
+  expect_snapshot(error = TRUE, calculate(gen_gss4, stat = "t"))
 
   # Check successful diff in props
   gen_gss4a <- gss_tbl %>%
@@ -190,7 +182,7 @@ test_that("response variable is a factor (two var problems)", {
   expect_silent(
     calculate(gen_gss4a, stat = "z", order = c("female", "male"))
   )
-  expect_warning(calculate(gen_gss4a, stat = "z"))
+  expect_snapshot(res_ <- calculate(gen_gss4a, stat = "z"))
 })
 
 gen_gss5 <- gss_tbl %>%
@@ -198,7 +190,7 @@ gen_gss5 <- gss_tbl %>%
   generate(reps = 10, type = "bootstrap")
 
 test_that("response variable is numeric (two var problems)", {
-  expect_error(calculate(gen_gss5, stat = "F"))
+  expect_snapshot(error = TRUE, calculate(gen_gss5, stat = "F"))
 })
 
 test_that("two sample mean-type problems are working", {
@@ -206,14 +198,14 @@ test_that("two sample mean-type problems are working", {
     specify(hours ~ college) %>%
     hypothesize(null = "independence") %>%
     generate(reps = 10, type = "permute")
-  expect_warning(calculate(gen_gss5a, stat = "diff in means"))
+  expect_snapshot(res_ <- calculate(gen_gss5a, stat = "diff in means"))
   expect_silent(
     calculate(gen_gss5a,
       stat = "diff in means",
       order = c("no degree", "degree")
     )
   )
-  expect_warning(calculate(gen_gss5a, stat = "t"))
+  expect_snapshot(res_ <- calculate(gen_gss5a, stat = "t"))
   expect_silent(calculate(gen_gss5a,
     stat = "t",
     order = c("no degree", "degree")
@@ -221,14 +213,14 @@ test_that("two sample mean-type problems are working", {
 })
 
 test_that("properties of tibble passed-in are correct", {
-  expect_is(gen_gss5, "grouped_df")
+  expect_s3_class(gen_gss5, "grouped_df")
   expect_equal(ncol(gen_gss5), 3)
 
   gen_gss6 <- gss_tbl %>%
     specify(hours ~ NULL) %>%
     generate(reps = 10)
   expect_equal(ncol(gen_gss6), 2)
-  expect_error(calculate(gen_gss6))
+  expect_snapshot(error = TRUE, calculate(gen_gss6))
 })
 
 test_that("order is working for diff in means", {
@@ -269,7 +261,7 @@ test_that("chi-square matches chisq.test value", {
       dplyr::select(replicate, stat = statistic)
   )
   # Equal not including attributes
-  expect_equivalent(infer_way, trad_way)
+  expect_equal(infer_way, trad_way, ignore_attr = TRUE)
 
   gen_gss9 <- gss_tbl %>%
     specify(partyid ~ NULL) %>%
@@ -286,7 +278,7 @@ test_that("chi-square matches chisq.test value", {
       stats::chisq.test(table(.$partyid))
     )) %>%
     dplyr::select(replicate, stat = statistic)
-  expect_equivalent(infer_way, trad_way)
+  expect_equal(infer_way, trad_way, ignore_attr = TRUE)
 
   gen_gss9a <- gss_tbl %>%
     specify(partyid ~ NULL) %>%
@@ -303,7 +295,7 @@ test_that("chi-square matches chisq.test value", {
       stats::chisq.test(table(.$partyid), p = c(0.8, 0.1, 0.1))
     )) %>%
     dplyr::select(replicate, stat = statistic)
-  expect_equivalent(infer_way, trad_way)
+  expect_equal(infer_way, trad_way, ignore_attr = TRUE)
 
   # check that dots are passed correctly
   dat <- data.frame(
@@ -325,7 +317,7 @@ test_that("chi-square matches chisq.test value", {
 
   expect_false(promote_f$stat == promote_t$stat)
 
-  expect_error(
+  expect_snapshot(error = TRUE,
     dat %>%
      specify(action ~ sex, success = "promote") %>%
      calculate(stat = "Chisq", order = c("male", "female"), correct = "boop")
@@ -339,24 +331,22 @@ test_that("chi-square works with factors with unused levels", {
   )
 
   # Unused levels in explanatory variable
-  expect_message(
+  expect_snapshot(
     out <- test_tbl %>%
       specify(y ~ x) %>%
       calculate(stat = "Chisq") %>%
-      pull(),
-    "Dropping unused factor levels.*explanatory"
+      pull()
   )
   expect_true(!is.na(out))
 
   # Unused levels in response variable
   test_tbl[["x"]] <- factor(test_tbl[["x"]])
   levels(test_tbl[["y"]]) <- c("e", "f", "g")
-  expect_message(
+  expect_snapshot(
     out <- test_tbl %>%
       specify(y ~ x) %>%
       calculate(stat = "Chisq") %>%
-      pull(),
-    "Dropping unused factor levels.*response"
+      pull()
   )
   expect_true(!is.na(out))
 })
@@ -366,26 +356,26 @@ test_that("`order` is working", {
     specify(hours ~ college) %>%
     hypothesize(null = "independence") %>%
     generate(reps = 10, type = "permute")
-  expect_error(
+  expect_snapshot(error = TRUE,
     calculate(gen_gss_tbl10, stat = "diff in means", order = c(TRUE, FALSE))
   )
 
   gen_gss_tbl11 <- gss_tbl %>%
     specify(hours ~ college) %>%
     generate(reps = 10, type = "bootstrap")
-  expect_error(
+  expect_snapshot(error = TRUE,
     calculate(gen_gss_tbl11,
       stat = "diff in medians",
       order = "no degree"
     )
   )
-  expect_error(
+  expect_snapshot(error = TRUE,
     calculate(gen_gss_tbl11,
       stat = "diff in medians",
       order = c(NA, "no degree")
     )
   )
-  expect_error(
+  expect_snapshot(error = TRUE,
     calculate(gen_gss_tbl11,
       stat = "diff in medians",
       order = c("no degree", "other")
@@ -397,16 +387,15 @@ test_that("`order` is working", {
       order = c("no degree", "degree")
     )
   )
-  expect_error(
+  expect_snapshot(error = TRUE,
     calculate(gen_gss_tbl11,
       stat = "diff in means",
       order = c("no degree", "degree", "the last one")
     )
   )
   # order not given
-  expect_warning(
-    calculate(gen_gss_tbl11, stat = "diff in means"),
-    "The statistic is based on a difference or ratio"
+  expect_snapshot(
+     res_ <- calculate(gen_gss_tbl11, stat = "diff in means")
   )
 })
 
@@ -424,7 +413,7 @@ test_that("NULL response gives error", {
   gss_tbl_improp <- tibble::as_tibble(gss_tbl) %>%
     dplyr::select(hours, age)
 
-  expect_error(gss_tbl_improp %>% calculate(stat = "mean"))
+  expect_snapshot(error = TRUE, gss_tbl_improp %>% calculate(stat = "mean"))
 })
 
 test_that("Permute F test works", {
@@ -449,14 +438,14 @@ test_that("order being given when not needed gives warning", {
     specify(college ~ partyid, success = "no degree") %>%
     hypothesize(null = "independence") %>%
     generate(reps = 10, type = "permute")
-  expect_warning(
-    calculate(gen_gss_tbl15, stat = "Chisq", order = c("dem", "ind"))
+  expect_snapshot(
+     res_ <- calculate(gen_gss_tbl15, stat = "Chisq", order = c("dem", "ind"))
   )
 })
 
 ## Breaks oldrel build. Commented out for now.
 # test_that("warning given if calculate without generate", {
-#   expect_warning(
+#   expect_snapshot(
 #     gss_tbl %>%
 #       specify(partyid ~ NULL) %>%
 #       hypothesize(
@@ -472,32 +461,31 @@ test_that("specify() %>% calculate() works", {
   expect_silent(
     gss_tbl %>% specify(hours ~ NULL) %>% calculate(stat = "mean")
   )
-  expect_message(
-    gss_tbl %>%
+  expect_snapshot(
+    res_ <- gss_tbl %>%
       specify(hours ~ NULL) %>%
       hypothesize(null = "point", mu = 4) %>%
       calculate(stat = "mean")
   )
 
-  expect_warning(
-    gss_tbl %>% specify(partyid ~ NULL) %>% calculate(stat = "Chisq")
+  expect_snapshot(
+     res_ <- gss_tbl %>% specify(partyid ~ NULL) %>% calculate(stat = "Chisq")
   )
 })
 
 test_that("One sample t hypothesis test is working", {
-  expect_message(
-    gss_tbl %>%
+  expect_snapshot(
+    res_ <- gss_tbl %>%
       specify(hours ~ NULL) %>%
       hypothesize(null = "point", mu = 1) %>%
       generate(reps = 10) %>%
       calculate(stat = "t")
   )
 
-  expect_warning(
-    gss_tbl %>%
+  expect_snapshot(
+     res_ <- gss_tbl %>%
       specify(response = hours) %>%
-      calculate(stat = "t"),
-    "A t statistic requires"
+      calculate(stat = "t")
   )
 
   gss_tbl %>%
@@ -508,17 +496,17 @@ test_that("One sample t hypothesis test is working", {
 test_that("specify done before calculate", {
   gss_tbl_mean <- gss_tbl %>%
     dplyr::select(stat = hours)
-  expect_error(calculate(gss_tbl_mean, stat = "mean"))
+  expect_snapshot(error = TRUE, calculate(gss_tbl_mean, stat = "mean"))
 
   gss_tbl_prop <- gss_tbl %>% dplyr::select(college)
   attr(gss_tbl_prop, "response") <- "college"
-  expect_error(calculate(gss_tbl_prop, stat = "prop"))
-  expect_error(calculate(gss_tbl_prop, stat = "count"))
+  expect_snapshot(error = TRUE, calculate(gss_tbl_prop, stat = "prop"))
+  expect_snapshot(error = TRUE, calculate(gss_tbl_prop, stat = "count"))
 })
 
 test_that("chisq GoF has params specified for observed stat", {
   no_params <- gss_tbl %>% specify(response = partyid)
-  expect_warning(calculate(no_params, stat = "Chisq"))
+  expect_snapshot(res_ <- calculate(no_params, stat = "Chisq"))
 
   params <- gss_tbl %>%
     specify(response = partyid) %>%
@@ -530,8 +518,8 @@ test_that("chisq GoF has params specified for observed stat", {
 })
 
 test_that("One sample t bootstrap is working", {
-  expect_warning(
-    gss_tbl %>%
+  expect_snapshot(
+     res_ <- gss_tbl %>%
       specify(hours ~ NULL) %>%
       generate(reps = 10, type = "bootstrap") %>%
       calculate(stat = "t")
@@ -579,9 +567,10 @@ test_that("calc_impl.sum works", {
     specify(hours ~ NULL) %>%
     generate(10)
 
-  expect_equivalent(
+  expect_equal(
     gen_gss_tbl16 %>% calculate(stat = "sum"),
-    gen_gss_tbl16 %>% dplyr::summarise(stat = sum(hours))
+    gen_gss_tbl16 %>% dplyr::summarise(stat = sum(hours)),
+    ignore_attr = TRUE
   )
 })
 
@@ -606,9 +595,10 @@ test_that("calc_impl.count works", {
     tolerance = eps
   )
 
-  expect_equivalent(
+  expect_equal(
     gen_gss_tbl12 %>% calculate(stat = "count"),
-    gen_gss_tbl12 %>% dplyr::summarise(stat = sum(college == "no degree"))
+    gen_gss_tbl12 %>% dplyr::summarise(stat = sum(college == "no degree")),
+    ignore_attr = TRUE
   )
 })
 
@@ -681,52 +671,45 @@ test_that("calc_impl.z works for one sample proportions", {
 })
 
 test_that("calculate warns informatively with insufficient null", {
-  expect_warning(
-    gss %>%
-      specify(response = sex, success = "female") %>%
-      calculate(stat = "z"),
-    "following null value: `p = .5`"
-  )
+   expect_snapshot(
+      res_ <- gss %>%
+         specify(response = sex, success = "female") %>%
+         calculate(stat = "z")
+   )
 
-  expect_warning(
-    gss %>%
-      specify(hours ~ NULL) %>%
-      calculate(stat = "t"),
-    "following null value: `mu = 0`"
-  )
+   expect_snapshot(
+      res_ <- gss %>%
+         specify(hours ~ NULL) %>%
+         calculate(stat = "t")
+   )
 
-  expect_warning(
-    gss %>%
-      specify(response = partyid) %>%
-      calculate(stat = "Chisq"),
-    "the following null values: `p = c(dem = 0.2",
-    fixed = TRUE
-  )
+   expect_snapshot(
+      res_ <- gss %>%
+         specify(response = partyid) %>%
+         calculate(stat = "Chisq")
+   )
 })
 
 test_that("calculate messages informatively with excessive null", {
-  expect_message(
-    gss %>%
+  expect_snapshot(
+    res_ <- gss %>%
       specify(hours ~ NULL) %>%
       hypothesize(null = "point", mu = 40) %>%
-      calculate(stat = "mean"),
-    "point null hypothesis `mu = 40` does not inform calculation"
+      calculate(stat = "mean")
   )
 
-  expect_message(
-    gss %>%
+  expect_snapshot(
+    res_ <- gss %>%
       specify(hours ~ NULL) %>%
       hypothesize(null = "point", sigma = 10) %>%
-      calculate(stat = "sd"),
-    "point null hypothesis `sigma = 10` does not inform calculation"
+      calculate(stat = "sd")
   )
 
-  expect_message(
-    gss %>%
+  expect_snapshot(
+    res_ <- gss %>%
       specify(hours ~ college) %>%
       hypothesize(null = "independence") %>%
-      calculate("diff in means", order = c("no degree", "degree")),
-    "independence null hypothesis does not inform calculation"
+      calculate("diff in means", order = c("no degree", "degree"))
   )
 })
 
@@ -753,21 +736,19 @@ test_that("calculate can handle variables named x", {
 })
 
 test_that("calculate errors out with multiple explanatory variables", {
-  expect_error(
+  expect_snapshot(error = TRUE,
     gss %>%
       specify(hours ~ age + college) %>%
       hypothesize(null = "independence") %>%
-      calculate(stat = "t"),
-    "Multiple explanatory variables.*in calculate"
+      calculate(stat = "t")
   )
 
-  expect_error(
+  expect_snapshot(error = TRUE,
     gss %>%
       specify(hours ~ age + college) %>%
       hypothesize(null = "independence") %>%
       generate(reps = 3, type = "permute") %>%
-      calculate(stat = "t"),
-    "Multiple explanatory variables.*in calculate"
+      calculate(stat = "t")
   )
 })
 
